This function decodes a vector or data frame column of SYNOP strings belonging to the same or different meteorological surface station.
Arguments
- data
A character vector, a data frame column containing raw SYNOP strings, or the exact data frame returned by
parse_ogimet().- wmo_identifier
A 5-digit character string or integer representing the station WMO ID. If NULL (default), all messages are decoded.
- remove_empty_cols
Logical. Should columns containing only
NAvalues be removed? Default is TRUE.
Value
A data frame where each row represents one observation time and each column a decoded meteorological variable.
wmo_id - WMO station identifier
Year - (from parse_ogimet())
Month - (from parse_ogimet())
Day - As informed by Section 0
Hour - As informed by Section 0
Cloud_base_height - Lowest cloud base height, in intervals
Visibility - In meters
Total_cloud_cover - In oktas, 9 means 'invisible' sky by fog or other phenomenon
Wind_direction - In tens of degree, 99 means 'variable wind direction'
Wind_speed
Wind_speed_unit - Either 'm/s' or 'knots'
Air_temperature - In degrees Celsius
Dew_point - In degrees Celsius
Relative_humidity - As a percentage
Station_pressure - In hPa
MSLP_GH - Mean sea level pressure (in hPa) or geopotential height (in gpm)
Pressure_tendency - In hPa
Charac_pressure_tend - String, simplified decoding
Precipitation_S1 - In mm
Precip_period_S1 - In hours ('Precipitation_S1' fell in the last 'Precip_period_S1' hours)
Present_weather - String, simplified decoding
Past_weather1 - String, simplified decoding
Past_weather2 - String, simplified decoding
Cloud_amount_Nh - Cloud coverage from low or medium cloud, same as 'Total_cloud_cover'
Low_clouds_CL - String, simplified decoding
Medium_clouds_CM - String, simplified decoding
High_clouds_CH - String, simplified decoding
Max_temperature - In degrees Celsius
Min_temperature - In degrees Celsius
Ground_state - String, simplified decoding
Ground_temperature - Integer, in degrees Celsius
Snow_ground_state - String, simplified decoding
Snow_depth - In cm
Ev_Evt - Evaporation (ev) or evapotranspiration (evt), in mm
Sunshine_daily - In hours (generally from the previous civil day)
Positive_Net_Rad_last_24h - In J/cm^2
Negative_Net_Rad_last_24h - In J/cm^2
Global_Solar_Rad_last_24h - In J/cm^2
Diffused_Solar_Rad_last_24h - In J/cm^2
Downward_LongWave_Rad_last_24h - In J/cm^2
Upward_LongWave_Rad_last_24h - In J/cm^2
ShortWave_Rad_last_24h - In J/cm^2
Net_ShortWave_Rad_last_24h - In J/cm^2
Direct_Solar_Rad_last_24h - In J/cm^2
Sunshine_last_hour - In hours
Positive_Net_Rad_last_hour - In kJ/m^2
Negative_Net_Rad_last_hour - In kJ/m^2
Global_Solar_Rad_last_hour - In kJ/m^2
Diffused_Solar_Rad_last_hour - In kJ/m^2
Downward_LongWave_Rad_last_hour - In kJ/m^2
Upward_LongWave_Rad_last_hour - In kJ/m^2
ShortWave_Rad_last_hour - In kJ/m^2
Net_ShortWave_Rad_last_hour - In kJ/m^2
Direct_Solar_Rad_last_hour - In kJ/m^2
Cloud_drift_direction - In cardinal and intercardinal directions for "low - medium - high" clouds
Cloud_elevation_direction - String indicating genera, direction and elevation angle
Pressure_change_last_24h - In hPa
Precipitation_S3 - In mm
Precip_period_S3 - In hours ('Precipitation_S3' fell in the last 'Precip_period_S3' hours)
Precipitation_last_24h - In mm
Cloud_layer_1 - String indicating cover, genera and height
Cloud_layer_2 - String indicating cover, genera and height
Cloud_layer_3 - String indicating cover, genera and height
Cloud_layer_4 - String indicating cover, genera and height
Examples
msg <- paste0("AAXX 01123 87736 32965 13205 10214 20143 ",
"30022 40113 5//// 80005 333 10236 20128 56000 81270=")
synop_df <- data.frame(messages = msg)
decoded_data <- show_synop_data(synop_df)